@@ -13,8 +13,9 @@
 # limitations under the License.
 
 from abc import ABC, abstractmethod
+from typing import NamedTuple, Tuple, Dict
+
 from towhee.dataframe import DataFrame
-from typing import NamedTuple, Tuple
 from towhee.utils.log import engine_log
 
 
@@ -33,7 +34,7 @@ class DataFrameWriter(ABC):
             engine_log.error('Ignore None data which try to write to dataframe %s',
                              self._output_df.name)
 
-    @ abstractmethod
+    @abstractmethod
     def _write(self, output_data: any):
         raise NotImplementedError
 
@@ -52,6 +53,17 @@ class NamedTupleDataFrameWriter(DataFrameWriter):
         self._output_df.put_dict(output_data._asdict())
 
 
+class DictDataFrameWriter(DataFrameWriter):
+    """
+    Df writer
+
+    Write dict to the next dataframe.
+    """
+
+    def _write(self, output_data: Dict[str, any]) -> None:
+        self._output_df.put_dict(output_data)
+
+
 class RowDataFrameWriter(DataFrameWriter):
     """
     Filter dataframe writer.
