@@ -12,13 +12,13 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-
 import importlib.util
 from pathlib import Path
 from typing import Any, Dict
 
 from towhee.operator import Operator
 from towhee.operator.nop import NOPOperator
+from towhee.operator.concat_operator import ConcatOperator
 from towhee.engine import LOCAL_OPERATOR_CACHE
 from towhee.hub.file_manager import FileManager
 
@@ -39,6 +39,15 @@ class OperatorLoader:
         else:
             self._cache_path = Path(cache_path)
 
+    def _load_interal_op(self, op_name: str, args: Dict[str, any]):
+        if op_name in ['_start_op', '_end_op']:
+            return NOPOperator()
+        elif op_name == '_concat':
+            return ConcatOperator(**args)
+        else:
+            # Not a interal operator
+            return None
+
     def load_operator(self, function: str, args: Dict[str, Any]) -> Operator:
         """Attempts to load an operator from cache. If it does not exist, looks up the
         operator in a remote location and downloads it to cache instead. By standard
@@ -54,8 +63,9 @@ class OperatorLoader:
                 Cannot find operator.
         """
 
-        if function in ['_start_op', '_end_op']:
-            return NOPOperator()
+        op = self._load_interal_op(function, args)
+        if op is not None:
+            return op
 
         fm = FileManager()
         path = fm.get_operator(function)
@@ -63,11 +73,9 @@ class OperatorLoader:
         if path is None:
             raise FileExistsError('Cannot find operator.')
 
-        fname = str(path).rsplit('/', maxsplit=1)[-1][:-3]
+        fname = Path(path).stem
         modname = 'towhee.operator.' + fname
-
-        spec = importlib.util.spec_from_file_location(
-            modname, path.resolve())
+        spec = importlib.util.spec_from_file_location(modname, path.resolve())
 
         # Create the module and then execute the module in its own namespace.
         module = importlib.util.module_from_spec(spec)
