@@ -64,8 +64,8 @@ class TestGeneratorRunner(unittest.TestCase):
         writer = MockWriter()
         runner = GeneratorRunner('test', 0, 'generator_operator',
                                  'mock_operators', {},
-                                 MockReader(data_queue), writer)
-        runner.set_op(generator_operator.GeneratoOperator())
+                                 [MockReader(data_queue)], writer)
+        runner.set_op(generator_operator.GeneratorOperator())
         t = threading.Thread(target=run, args=(runner, ))
         t.start()
         self.assertEqual(runner.status, RunnerStatus.RUNNING)
@@ -94,8 +94,8 @@ class TestGeneratorRunner(unittest.TestCase):
         writer = MockWriter()
         runner = GeneratorRunner('test', 0, 'generator_operator',
                                  'mock_operators', {},
-                                 MockReader(data_queue), writer)
-        runner.set_op(generator_operator.GeneratoOperator())
+                                 [MockReader(data_queue)], writer)
+        runner.set_op(generator_operator.GeneratorOperator())
         t = threading.Thread(target=run, args=(runner, ))
         t.start()
         data_queue.put('error_data')
